@@ -12,6 +12,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 import time
+import ntpath
 
 try:
     import paramiko
@@ -60,10 +61,11 @@ class PythonSSHClient(AbstractSSHClient):
         paramiko.util.log_to_file(path)
         return True
 
-    def _login(self, username, password):
+    def _login(self, username, password, look_for_keys=False):
         try:
             self.client.connect(self.config.host, self.config.port, username,
-                                password, look_for_keys=False, allow_agent=False,
+                                password, look_for_keys=look_for_keys,
+                                allow_agent=look_for_keys,
                                 timeout=float(self.config.timeout))
         except paramiko.AuthenticationException:
             raise SSHClientException
@@ -159,11 +161,14 @@ class SFTPClient(AbstractSFTPClient):
 
     def _absolute_path(self, path):
         path = path.encode(self._encoding)
-        normalized_path = self._client.normalize(path)
-        if not isinstance(normalized_path, unicode):
-            normalized_path = unicode(normalized_path, self._encoding)
-        return normalized_path
+        if not self._is_windows_path(path):
+            path = self._client.normalize(path)
+        if not isinstance(path, unicode):
+            path = unicode(path, self._encoding)
+        return path
 
+    def _is_windows_path(self, path):
+        return bool(ntpath.splitdrive(path)[0])
 
 class RemoteCommand(AbstractCommand):
 
